Crate bevy_descendant_collector

Crate bevy_descendant_collector 

Structs

DescendantCollectorPlugin
This plugin is generic over different types of aggregator that you define. The default implementation is for Scenes using HierarchyRootPosition::Scene
DescendantCollectorTarget

Enums

HierarchyRootPosition

Traits

DescendantLoader
Implemented by the EntityCollectorTarget derive trait, used by the DescendantCollectorPlugin

Functions

collect_named_entity_paths
find_named_entity
find_named_grandchild

Derive Macros

EntityCollectorTarget
Inserts this component to freshly spawned scenes marked with a generic component